Guides for SDK
==============

Open Telekom Cloud related User Guides
--------------------------------------

.. toctree::
   :maxdepth: 1

   anti_ddos
   auto_scaling
   cbr
   cce
   ces
   css
   cts
   dcaas
   dcs
   deh
   dis
   dms
   dns
   dws
   function_graph
   kms
   lts
   mrs
   modelarts
   nat
   obs
   rds
   sfsturbo
   smn
   vpc
   vpcep
   logging
   apig

.. _user_guides:

User Guides
-----------

The Open Telekom Cloud services are covering OpenStack native services and
enhanced ones covering additional functionalities. All user guides related
to Open Telekom Cloud are listed above. The links links to the most important
OpenStack native services are listed below.

OpenStack native User Guides
----------------------------

.. toctree::
   :maxdepth: 1

   Block Storage <https://docs.openstack.org/openstacksdk/latest/user/guides/block_storage>
   Compute <https://docs.openstack.org/openstacksdk/latest/user/guides/compute>
   Identity <https://docs.openstack.org/openstacksdk/latest/user/guides/identity>
   Image <https://docs.openstack.org/openstacksdk/latest/user/guides/image>
   Key Manager <https://docs.openstack.org/openstacksdk/latest/user/guides/key_manager>
   Message <https://docs.openstack.org/openstacksdk/latest/user/guides/message>
   Microversions <https://docs.openstack.org/openstacksdk/latest/user/microversions>
   Network <https://docs.openstack.org/openstacksdk/latest/user/guides/network>
   Object Store <https://docs.openstack.org/openstacksdk/latest/user/guides/object_store>
   Using Cloud Abstration Layer <https://docs.openstack.org/openstacksdk/latest/user/usage>
